import {
  select,csv,scaleLinear,extent,axisLeft,axisBottom
  ,format,scaleTime,line,curveBasis,timeFormat
} from 'd3';

export const scatterPlot = (selection, props) => {
	const{
    xValue,
  	xAxisLabel,
  	yValue,
   	yAxisLabel,
    width,
    height,
    margin,
    data 
  }=props;
  


  const innerwidth = width - margin.right -margin.left;
  const innerheight = height - margin.top - margin.bottom;
  
  
  //data transformation
  const xScale = scaleTime()
  .domain(extent(data,xValue))
  .range([0,innerwidth]);

  const yScale = scaleLinear()
  .domain(extent(data,yValue))
  .range([innerheight,0])
  .nice();
  
  
  //Margin
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g.enter().append('g')
 			 	.attr('class','container');
  gEnter.merge(g)	
        .attr('transform',`translate(${margin.left},${margin.top})`);
  
  
  //draw Xaxis
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerheight)
  	.tickPadding(10);
  
  const xAxisG = g.select('.x-axis')
  const xAxisGEnter = gEnter
       .append('g')
          .attr('class','x-axis');

  xAxisG.merge(xAxisGEnter)
  			.attr('transform',`translate(0,${innerheight})`)
        .call(xAxis)	
        .selectAll('.domain').remove();
 
  
  //draw Yaxis
  const yAxis = axisLeft(yScale)
  		.tickSize(-innerwidth)
  		.tickPadding(10);;
  
 
   const yAxisG = g.select('.y-axis');
   const yAxisGEnter = gEnter
   .append('g')
   		.attr('class','y-axis');
  
   yAxisG.merge(yAxisGEnter)  
   				.call(yAxis) 
   				.selectAll('.domain').remove()
   		;
  
  
  //Axis lable
  const xAxisLabelText = xAxisGEnter
  			.append('text')
  			.attr('class','axis-label')
    		.attr('y',40)
  			.attr('fill','black')
  			.merge(xAxisG.select('axis-label'))				
  					.attr('x',innerwidth/2)
  					.text(xAxisLabel);
  
  
  const yAxisLabelText = yAxisGEnter
  			.append('text')
  			.attr('class','axis-label')
    		.attr('y',-43)
  			.attr('fill','black')
  			.attr('transform',`rotate(-90)`)
  			.attr('text-anchor','middle')
  			.merge(yAxisG.select('axis-label'))
  					.attr('x',-innerheight/2)
  					.text(yAxisLabel);
 

  
  //draw path  
	const lineGen = line()
  	.x(d=>xScale(xValue(d)))
  	.y(d=>yScale(yValue(d)))
  	.curve(curveBasis);
  	
  const lineG = g.select('.line-path');
  const lineGEnter = gEnter.append('path')
  	.attr('class','line-path');
   
  lineG.merge(lineGEnter)
  .transition().duration(1000)
  	 .attr('d',lineGen(data))
     ;
  

  
};